@@ -17,7 +17,7 @@
  *          Matthew Saltzman, Clemson University                             *
  *                                                                           * 
  *                                                                           *
- * Copyright (C) 2001-2006, Lehigh University, Yan Xu, and Ted Ralphs.       *
+ * Copyright (C) 2001-2008, Lehigh University, Yan Xu, and Ted Ralphs.       *
  *===========================================================================*/
 
 #include <cassert>
@@ -180,7 +180,7 @@ AbcTreeNode::process(bool isRoot, bool rampUp)
 	AbcSolution* sol = new AbcSolution(numCols, 
 					   m->bestSolution(),
 					   m->getObjValue());
-	getKnowledgeBroker()->addKnowledge(ALPS_SOLUTION, sol, 
+	getKnowledgeBroker()->addKnowledge(AlpsKnowledgeTypeSolution, sol, 
 					   m->getObjValue());
     }
     
@@ -213,7 +213,8 @@ AbcTreeNode::process(bool isRoot, bool rampUp)
 		AbcSolution* ksol = new AbcSolution(numCols, 
 						    m->getColSolution(), 
 						    val);
-		getKnowledgeBroker()->addKnowledge(ALPS_SOLUTION, ksol, val); 
+		getKnowledgeBroker()->addKnowledge(AlpsKnowledgeTypeSolution, 
+						   ksol, val); 
 	    }
 	    setStatus(AlpsNodeStatusFathomed);
 	}
@@ -233,8 +234,8 @@ AbcTreeNode::process(bool isRoot, bool rampUp)
 			AbcSolution *sol = new AbcSolution(numCols, 
 							   m->bestSolution(),
 							   m->getObjValue());
-			getKnowledgeBroker()->addKnowledge(ALPS_SOLUTION, sol, 
-							   m->getObjValue());
+			getKnowledgeBroker()->addKnowledge(
+                           AlpsKnowledgeTypeSolution, sol, m->getObjValue());
 			
 		    }	
 		    if (action == -1) { 
@@ -413,7 +414,7 @@ AbcTreeNode::encode() const
 #if defined(ABC_DEBUG_MORE)
     std::cout << "AbcTreeNode::encode()--start to encode" << std::endl;
 #endif
-    AlpsEncoded* encoded = new AlpsEncoded("ALPS_NODE");
+    AlpsEncoded* encoded = new AlpsEncoded(AlpsKnowledgeTypeNode);
     AbcNodeDesc* desc = dynamic_cast<AbcNodeDesc*>(desc_);
     AbcModel* model = dynamic_cast<AbcModel*>(desc->getModel());
 
@@ -1095,8 +1096,7 @@ int AbcTreeNode::chooseBranch(AbcModel *model, bool& strongFound)
 	    pseudoC = model->getPseudoList()[object];
 	    upCost = pseudoC->upCost_ * (1.0 - fraction);
 	    downCost = pseudoC->downCost_ * fraction;
-	    deg = 4.0 * std::min(upCost, downCost) +
-		1.0 * std::max(upCost, downCost);
+	    deg = 4.0 * min(upCost, downCost) + 1.0 * max(upCost, downCost);
 	    if (deg > mostDeg) {
 		mostDeg = deg;
 		mostInd = object;
