@@ -17,7 +17,7 @@
  *          Matthew Saltzman, Clemson University                             *
  *                                                                           * 
  *                                                                           *
- * Copyright (C) 2001-2007, Lehigh University, Yan Xu, and Ted Ralphs.       *
+ * Copyright (C) 2001-2008, Lehigh University, Yan Xu, and Ted Ralphs.       *
  * All Rights Reserved.                                                      *
  *===========================================================================*/
 
@@ -27,6 +27,8 @@
 #include <cfloat>
 #include <cstdio>
 
+#include "CoinFinite.hpp"
+
 //#############################################################################
 
 #if defined(__linux__)
@@ -42,6 +44,15 @@ enum AlpsClockType {
    AlpsClockTypeWallClock
 };
 
+//#############################################################################
+/** The possible values for static load balancing scheme. */
+//#############################################################################
+
+enum AlpsStaticBalanceScheme {
+    AlpsRootInit = 0,
+    AlpsSpiral
+};
+
 //#############################################################################
 /** The possible stati for the search nodes. */
 //#############################################################################
@@ -126,14 +137,14 @@ enum AlpsPhase {
 // Big number
 //#############################################################################
 
-#define ALPS_DBL_MAX          DBL_MAX
+#define ALPS_DBL_MAX          COIN_DBL_MAX
 #define ALPS_INC_MAX          1.0e80
 #define ALPS_OBJ_MAX          1.0e75
 #define ALPS_OBJ_MAX_LESS     1.0e70
 #define ALPS_BND_MAX          1.0e20
 #define ALPS_INFINITY         1.0e20
 
-#define ALPS_INT_MAX          INT_MAX
+#define ALPS_INT_MAX          COIN_INT_MAX
 
 //#############################################################################
 // Small number
@@ -142,6 +153,9 @@ enum AlpsPhase {
 #define ALPS_ZERO             1.0e-14
 #define ALPS_GEN_TOL          1.0e-6
 #define ALPS_QUALITY_TOL      1.0e-5
+#define ALPS_SMALL_3          1.0e-3
+#define ALPS_SMALL_4          1.0e-4
+#define ALPS_SMALL_5          1.0e-5
 
 //#############################################################################
 
