@@ -17,7 +17,7 @@
  *          Matthew Saltzman, Clemson University                             *
  *                                                                           * 
  *                                                                           *
- * Copyright (C) 2001-2007, Lehigh University, Yan Xu, and Ted Ralphs.       *
+ * Copyright (C) 2001-2008, Lehigh University, Yan Xu, and Ted Ralphs.       *
  *===========================================================================*/
 
 #include "iomanip"
@@ -32,11 +32,6 @@ AlpsKnowledgeBrokerSerial::initializeSearch(int argc,
 					    char* argv[], 
 					    AlpsModel& model) {
 
-    if (msgLevel_ > 0) {
-        messageHandler()->message(ALPS_S_VERSION, messages())
-            << CoinMessageEol;
-    }
-    
     // Store a pointer to model
     model.setKnowledgeBroker(this);
     model_ = &model;
@@ -47,6 +42,23 @@ AlpsKnowledgeBrokerSerial::initializeSearch(int argc,
 
     model.readParameters(argc, argv);
 
+    //--------------------------------------------------
+    // Set up messege, logfile.
+    //--------------------------------------------------
+
+    msgLevel_ = model_->AlpsPar()->entry(AlpsParams::msgLevel);
+    messageHandler()->setLogLevel(msgLevel_);
+    
+    logFileLevel_ = model_->AlpsPar()->entry(AlpsParams::logFileLevel);
+    if (logFileLevel_ > 0) {    // Require log file
+	logfile_ = model_->AlpsPar()->entry(AlpsParams::logFile);
+    }
+    
+    if (msgLevel_ > 0) {
+        messageHandler()->message(ALPS_S_VERSION, messages())
+            << CoinMessageEol;
+    }
+
     //--------------------------------------------------
     // If there two args: xecutable + instance.
     //--------------------------------------------------
@@ -137,18 +149,6 @@ AlpsKnowledgeBrokerSerial::initializeSearch(int argc,
     model.preprocess();
     model.setupSelf();
 
-    //--------------------------------------------------
-    // Set up messege, logfile.
-    //--------------------------------------------------
-
-    msgLevel_ = model_->AlpsPar()->entry(AlpsParams::msgLevel);
-    messageHandler()->setLogLevel(msgLevel_);
-    
-    logFileLevel_ = model_->AlpsPar()->entry(AlpsParams::logFileLevel);
-    if (logFileLevel_ > 0) {    // Require log file
-	logfile_ = model_->AlpsPar()->entry(AlpsParams::logFile);
-    }
-    
     //--------------------------------------------------
     // Set up solution pool and subtree pool, set comparision.
     //--------------------------------------------------
@@ -267,7 +267,7 @@ AlpsKnowledgeBrokerSerial::searchLog()
 
 	if (hasKnowledge(AlpsKnowledgeTypeSolution)) {
 	    messageHandler()->message(ALPS_S_FINAL_SOL, messages())
-		<< getBestQuality() << CoinMessageEol;
+		<< getBestQuality() << bestSolDepth_ << CoinMessageEol;
 	}
 	else {
 	    messageHandler()->message(ALPS_S_FINAL_NO_SOL, messages())
@@ -304,7 +304,7 @@ AlpsKnowledgeBrokerSerial::searchLog()
 	    fout << "Best solution quality = " << getBestQuality() << std::endl;
 	}
 	else {
-	    fout << "Not solution found" << std::endl;
+	    fout << "No solution was found." << std::endl;
 	}
 	fout << "Number of nodes processed = "<<nodeProcessedNum_ << std::endl;
 	fout << "Number of nodes left = " << nodeLeftNum_ << std::endl;
