@@ -17,7 +17,7 @@
  *          Matthew Saltzman, Clemson University                             *
  *                                                                           * 
  *                                                                           *
- * Copyright (C) 2001-2007, Lehigh University, Yan Xu, and Ted Ralphs.       *
+ * Copyright (C) 2001-2008, Lehigh University, Yan Xu, and Ted Ralphs.       *
  *===========================================================================*/
 
 #ifndef AlpsKnowledgeBrokerSerial_h_
@@ -38,11 +38,23 @@ class AlpsKnowledgeBrokerSerial : public AlpsKnowledgeBroker {
     AlpsKnowledgeBrokerSerial& operator=(const AlpsKnowledgeBrokerSerial&);
 
  public:
+    /** Default constructor. */
     AlpsKnowledgeBrokerSerial() 
 	: 
 	AlpsKnowledgeBroker() 
 	{} 
 
+    /** Userful constructor. 
+	Note need read in parameters and data seperately. */
+    AlpsKnowledgeBrokerSerial(AlpsModel& model) 
+	: 
+	AlpsKnowledgeBroker() 
+	{
+	    initializeSearch(0, NULL, model); 
+	}   
+
+    /** Userful constructor. 
+	Read in parameters from arguments. Also read in data. */
     AlpsKnowledgeBrokerSerial(int argc, 
 			      char* argv[], 
 			      AlpsModel& model) 
@@ -52,6 +64,10 @@ class AlpsKnowledgeBrokerSerial : public AlpsKnowledgeBroker {
 	    initializeSearch(argc, argv, model); 
 	}
 
+
+    /** Destructor. */
+    virtual ~AlpsKnowledgeBrokerSerial() {}
+
     //-------------------------------------------------------------------------
     /** @name Report the search results.
      *  
@@ -80,6 +96,9 @@ class AlpsKnowledgeBrokerSerial : public AlpsKnowledgeBroker {
     /** The process outputs the best solution and the quality 
 	that it finds to a file or std::out. */
     virtual void printBestSolution(char* outputFile = 0) const {
+
+	if (msgLevel_ < 1) return;
+	
 	if (getNumKnowledges(AlpsKnowledgeTypeSolution) <= 0) {
 	    std::cout << "\nALPS did not find a solution."
 		      << std::endl;
@@ -89,19 +108,30 @@ class AlpsKnowledgeBrokerSerial : public AlpsKnowledgeBroker {
             // Write to outputFile
 	    std::ofstream os(outputFile);
 	    os << "============================================" << std::endl;
-	    os << "Best solution:" << std::endl;
-	    os << "Quality = " << getBestQuality();
+	    if (getSolStatus() == AlpsExitStatusOptimal) {
+		os << "Optimal solution:" << std::endl;
+	    }
+	    else {
+		os << "Best solution found:" << std::endl;
+	    }
+	    os << "Cost = " << getBestQuality();
 	    os << std::endl;
 	    dynamic_cast<AlpsSolution* >
 		(getBestKnowledge(AlpsKnowledgeTypeSolution).first)->print(os);
 	}
 	else {                                  // Write to std::cout
 	    std::cout << "============================================" << std::endl;
-	    std::cout << "Best solution:" << std::endl;
-	    std::cout << "Quality = " << getBestQuality();
+	    if (getSolStatus() == AlpsExitStatusOptimal) {
+		std::cout << "Optimal solution:" << std::endl;
+	    }
+	    else {
+		std::cout << "Best solution found:" << std::endl;
+	    }
+	    std::cout << "Cost = " << getBestQuality();
 	    std::cout << std::endl;
 	    dynamic_cast<AlpsSolution* >
 		(getBestKnowledge(AlpsKnowledgeTypeSolution).first)->print(std::cout);
+	    std::cout << "============================================" << std::endl;
 	}
     }
     //@}
