@@ -17,7 +17,7 @@
  *          Matthew Saltzman, Clemson University                             *
  *                                                                           * 
  *                                                                           *
- * Copyright (C) 2001-2007, Lehigh University, Yan Xu, and Ted Ralphs.       *
+ * Copyright (C) 2001-2008, Lehigh University, Yan Xu, and Ted Ralphs.       *
  *===========================================================================*/
 
 #ifndef AlpsMessageTag_h
@@ -33,7 +33,7 @@ enum AlpsMessageTag{
   /** The message tag indicating that the send ask the recv to
       continue or terminate. */
   // 0
-  AlpsMsgContOrTerm,
+  AlpsMsgContOrTerm = 0,
 
   /** Ask the receiver worker to donor workload to the specified worker. */
   // 1
@@ -69,8 +69,6 @@ enum AlpsMessageTag{
   // 8
   AlpsMsgAskTerminate,
 
-  AlpsMsgErrorCode,
-
   /** The message tag indicating that the process sent the message is idle. */
   // 9
   AlpsMsgIdle,
@@ -154,45 +152,63 @@ enum AlpsMessageTag{
   // 29
   AlpsMsgTellHubRecv,
 
-  // 31
+  // 30
   AlpsMsgIndicesFromMaster,
 
-  // 32
+  // 31
   AlpsMsgWorkerAskIndices,
 
-  // 34
+  // 32
   AlpsMsgForceTerm,
 
-  // 35
+  // 33
   AlpsMsgMasterIncumbent,
 
-  // 36
+  // 34
   AlpsMsgHubIncumbent,
 
-  // 37
+  // 35
   AlpsMsgAskHubPause,
+
   /** Ask the receiver worker to donor workload to the specified worker. */
-  // 38
+  // 36
   AlpsMsgAskDonateToWorker,
   
-  // 39
+  // 37
   AlpsMsgSubTreeByWorker,
 
-  // 40
+  // 38
   AlpsMsgIncumbentTwo,
   
   /** The message tag indicating that knowledge generated during rampup about
       model is being sent or received. */
-  // 41
+  // 39
   AlpsMsgModelGenRampUp,
+
   /** The message tag indicating that knowledge generated during search about
       model is being sent or received. */
-  // 42
+  // 40
   AlpsMsgModelGenSearch,
 
   /** When requested by master during inter balance, hub failed to identify 
       a donor worker. */
-  AlpsMsgHubFailFindDonor
+  // 41
+  AlpsMsgHubFailFindDonor,
+
+  /** Load info during ramp up */
+  // 42
+  AlpsMsgRampUpLoad,
+
+  /** Donate during ramp up */
+  // 43
+  AlpsMsgRampUpDonate,
+
+  /** Hub finished ramp up. Used in spiral method. */
+  // 44
+  AlpsMsgFinishInitHub,
+
+  /** Error code. */
+  AlpsMsgErrorCode
 };
 
 #endif
