@@ -16,7 +16,7 @@
  *          Laszlo Ladanyi, IBM T.J. Watson Research Center                  *
  *          Matthew Saltzman, Clemson University                             *
  *                                                                           *
- * Copyright (C) 2001-2007, Lehigh University, Yan Xu, and Ted Ralphs.       *
+ * Copyright (C) 2001-2008, Lehigh University, Yan Xu, and Ted Ralphs.       *
  * All Rights Reserved.                                                      *
  *===========================================================================*/
 
@@ -100,7 +100,7 @@ class BcpsSolution : public AlpsSolution {
     inline int getSize() const { return size_; }
     inline const BcpsObject_p* getObjects() const { return objects_; }
     inline const double* getValues() const { return values_; }
-    inline const double getQuality() const { return quality_; }
+    inline double getQuality() const { return quality_; }
     /**@} */
 
    /** Set/assign the appropriate data member. */
